@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 1998-2019 CS-SI. All Rights Reserved.
+* Copyright (C) 1998-2020 CS GROUP - France. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -252,7 +252,7 @@ static int set_rotation_size_offset(prelude_option_t *opt, const char *arg, prel
         else if ( *eptr == 'G' || *eptr == 'g' )
                 value = value * 1024 * 1024 * 1024;
 
-        else if ( eptr != arg ) {
+        else if ( *eptr != '\0' ) {
                 prelude_string_sprintf(err, "Invalid max rotation size offset specified: %s.", arg);
                 return -1;
         }
